@@ -47,6 +47,7 @@ function(x,
 		sample=NULL,
 		origin_x=NULL,
 		origin_data=NULL
+		
 
 
 ) {
@@ -98,6 +99,11 @@ function(x,
 		
 	
 	
+	} else if (sample=="monthly_year"){
+	 
+	# TO DO 	year <-
+		# TO DO 
+		
 	} else {
 		
 		print("Error in normalizaGaussian_sevaralStation: sample option not yet implemented!!")
